# FSMate

## TODO:
- [x] Support for custom state getter/setter
- [x] Overload methods depending on current state
- [ ] Transitions graph validation
- [ ] Callbacks or pre/post-transition hooks
- [ ] Async/await support
